import { queryOne, create, update } from '../../services/order';
import pathToRegexp from 'path-to-regexp';
import { Codes } from '../../utils/config';

export default {
  namespace: 'orderDetail',

  state: {
    filters: {},
    operType: 'create',
    currentItem: {},
    itemLoading: false,
    terminalModalShow: false,
    productModalShow: false,
  },

  subscriptions: {
    setup({ dispatch, history }) {
      history.listen(({ pathname, state, ...rest }) => {
        const match = pathToRegexp('/order/profile/:id').exec(pathname);
        if (match) {
          dispatch({ type: 'query', payload: { id: match[1] } });
          dispatch({ type: 'saveFilters', payload: state });
          dispatch({ type: 'saveOperType', payload: { operType: 'view' } });
        }
      });
    }
  },

  effects: {
    * query ({ payload }, { call, put }) {
      yield put({ type: 'changeLoading', payload: { itemLoading: true } });
      const { data, success } = yield call(queryOne, payload);
      if (success) {
        yield put({ type: 'querySuccess', payload: { ...data } });
      }
      yield put({ type: 'changeLoading', payload: { itemLoading: false } });
    },
    * create ({ payload, callback }, { call, put }) {
      const { data, success } = yield call(create, { ...payload });
      if (success) {
        yield put({ type: 'initState' });
        if (callback) callback();
      }
    },
    * update ({ payload, callback }, { call, put }) {
      const { data, success } = yield call(update, payload);
      if (success) {
        yield put({ type: 'initState' });
        if (callback) callback();
      }
    }
  },

  reducers: {
    changeLoading(state, { payload }) {
      return { ...state, ...payload };
    },
    querySuccess(state, { payload }) {
      return { ...state, currentItem: payload };
    },
    saveFilters(state, { payload: filters }) {
      return { ...state, filters };
    },
    showTerminalModal(state, action) {
      return { ...state, ...action.payload, terminalModalShow: true };
    },
    hideTerminalModal(state, action) {
      return { ...state, ...action.payload, terminalModalShow: false };
    },
    showProductModal(state, action) {
      return { ...state, ...action.payload, productModalShow: true };
    },
    hideProductModal(state, action) {
      return { ...state, ...action.payload, productModalShow: false };
    },
    // savePickedTerminal(state, action) {
    //   return {
    //     ...state,
    //     currentItem: { ...state.currentItem, ...action.payload },
    //     terminalModalShow: false,
    //   };
    // },
    // savePickedProducts(state, action) {
    //   return {
    //     ...state,
    //     currentItem: { goods: action.payload },
    //     productModalShow: false,
    //   };
    // },
    initState(state) {
      return { ...state, currentItem: {}, itemLoading: false };
    }
  }
}
