import React, { Component } from 'react';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import queryString from 'query-string';
import {
  Popover,
  Modal,
  Card,
  List,
  Form,
  Table,
  Button,
  Input,
  InputNumber,
  Select,
  Icon,
} from 'antd';

import PageHeaderLayout from '../../../layouts/PageHeaderLayout';
import FooterToolbar from '../../../components/FooterToolbar';
import TerminalSelectModal from './terminal';
import MerchantProductSelectModal from './product';
import { productType, pageSize, Codes } from '../../../utils/config';
import styles from './index.less';

@Form.create()
@connect(state => ({
  terminal: state.terminal,
  orderDetail: state.orderDetail,
  mproduct: state.mproduct,
}))
export default class CreateOrder extends Component {
  state = {
    userInfo: {}, //记录终端用户信息
    products: [], //记录选择的产品
  };

  // 终端选择弹框,显示 -> 加载数据
  handleTerminalSelectBtnClick = () => {
    this.props.dispatch({ type: 'orderDetail/showTerminalModal' });
    this.props.dispatch({
      type: 'terminal/query',
      payload: {
        pageNo: 1,
        pageSize,
      }
    });
  }

  // 选择终端
  handleTerminalModalOk = (record) => {
    // this.props.dispatch({
    //   type: 'orderDetail/savePickedTerminal',
    //   payload: {
    //     userCode: record.code,
    //     userName: record.name,
    //     campusName: record.campusName,
    //     merchantName: record.merchantName,
    //     merchantId: record.merchantId,
    //   }
    // });
    this.setState({
      userInfo: {
        userCode: record.code,
        userName: record.name,
        campusName: record.campusName,
        merchantName: record.merchantName,
        merchantId: record.merchantId,
        contactName: record.contactName,
        mobile: record.mobile,
        address: record.address,
      }
    });
    this.props.dispatch({ type: 'orderDetail/hideTerminalModal' });
  }

  handleTerminalModalCancel = () => {
    this.props.dispatch({ type: 'orderDetail/hideTerminalModal' });
  }

  handleTerminalModalSearch = () => {

  }

  handleTerminalModalTableChange = () => {

  }

  // 产品选择弹框
  handleProductSelectBtnClick = () => {
    const { orderDetail } = this.props;
    const { currentItem } = orderDetail;
    const { merchantId } = currentItem;
    this.props.dispatch({ type: 'orderDetail/showProductModal' });
    this.props.dispatch({
      type: 'mproduct/query',
      payload: {
        pageNo: 1,
        pageSize,
        merchantId,
      },
    });
  }

  handleProductModalSearch = () => {

  }

  handleProductModalTableChange = () => {

  }

  // 选择产品
  handleProductModalOk = (data) => {
    // this.props.dispatch({
    //   type: 'orderDetail/savePickedProducts',
    //   payload: data,
    // });
    this.setState({ products: data || [] });
    this.props.dispatch({ type: 'orderDetail/hideProductModal' });
  }

  handleProductModalCancel = () => {
    this.props.dispatch({ type: 'orderDetail/hideProductModal' });
  }

  handleListItemDel = (record) => {
    Modal.confirm({
      title: '确定从清单中删除此商品?',
    });
  }

  handlePageCancel = () => {
    const { orderDetail, dispatch } = this.props;
    const { filters } = orderDetail;
    dispatch(routerRedux.push({
      pathname: '/order',
      search: queryString.stringify(filters),
    }));
  }

  /**
   * @desc 对返回的单个订单数据进行加工，方便在table中进行展示及编辑
   * @param {Object}
   * @return {Object}
   */
  formatTableDatas = (data) => {
    const fmtProducts = data.map(item => {
      // 课程包类型的产品加入children字段
      if (item.type == Codes.CODE_PACKAGE) {
        item.children = item.contents;
        item.isChild = true;
      }
      // 把goods列表的第一项设置为默认选中项
      if (item.goods && item.goods.length) {
        item.goods.map((goodsItem, index) => {
          if (index == 0) {
            const defaultQuantity = 1;
            const defaultPrice = item.goods[0].terminalPrice;
            item.goods[0].selected = true;
            item.goods[0].quantity = 1;
            item.goods[0].rowSum = defaultPrice * defaultQuantity;
          }
        });
      } else {
        item.goods = [];
      }
      return item;
    });
    return fmtProducts;
  }

  render() {
    const { orderDetail, terminal, mproduct, form } = this.props;
    const { userInfo, products } = this.state;
    const { getFieldDecorator } = form;
    const { terminalModalShow, productModalShow } = orderDetail;
    const fmtProducts = this.formatTableDatas(products);

    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 2 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 12 },
        md: { span: 22 },
      },
    };

    const columns = [{
      title: '序号',
      dataIndex: 'sort',
      render: (text, record, index) => index + 1,
      width: '6%',
      key: 0,
    },{
      title: '编号',
      dataIndex: 'code',
      key: 1,
      width: '10%',
    },{
      title: '名称',
      dataIndex: 'name',
      key: 2,
      width: '10%',
    },{
      title: '类型',
      dataIndex: 'type',
      key: 3,
      render: (text) => productType[text],
      width: '6%',
    },{
      title: '价格类型',
      dataIndex: 'goods',
      key: 4,
      render: (text, record) => {
        if (!record.isChild) {
          return (
            <Select
              value={record.goods.filter(item => item.selected)[0].id}
            >
              {record.goods.map(item => <Select.Option key={item.id} value={item.id}>{`¥${item.terminalPrice} / ${item.chargeUnit}`}</Select.Option>)}
            </Select>
          );
        } else {
          return '-';
        }
      },
      width: '15%',
    },{
      title: '供应商售价',
      dataIndex: 'cpPrice',
      key: 5,
      render: (text, record) => {
        if (!record.isChild) {
          return record.goods.filter(item => item.selected)[0].cpPrice;
        } else {
          return '-';
        }
      },
      width: '10%',
    },{
      title: '领教售价',
      dataIndex: 'merchantPrice',
      key: 6,
      render: (text, record) => {
        if (!record.isChild) {
          return record.goods.filter(item => item.selected)[0].merchantPrice;
        } else {
          return '-';
        }
      },
      width: '10%',
    },{
      title: '渠道售价',
      dataIndex: 'terminalPrice',
      key: 7,
      render: (text, record) => {
        if (!record.isChild) {
          return record.goods.filter(item => item.selected)[0].terminalPrice;
        } else {
          return '-';
        }
      },
      width: '10%',
    },{
      title: '数量',
      dataIndex: 'quantity',
      key: 8,
      render: (text, record) => {
        if (!record.isChild || record.type == Codes.CODE_SUPPORT) {
          return (
            <InputNumber
              min={1}
              value={text}
              formatter={value => `x ${value}`.replace(/\B(?=(\d{3})+(?!\d))/g, ',')}
              parser={value => value.replace(/\x\s?|(,*)/g, '')}
            />
          );
        } else {
          return '-';
        }
      },
      width: '6%',
    },{
      title: '小计',
      dataIndex: 'rowSum',
      key: 9,
      width: '10%',
    },{
      title: '操作',
      dataIndex: 'operation',
      key: 10,
      render: (text, record) => {
        if (!record.isChild) {
          return <a onClick={() => this.handleListItemDel(record)}>删除</a>;
        } else {
          return;
        }
      },
      width: '7%',
    }];

    return (
      <PageHeaderLayout>
        <Card>
          <Form>
            <Form.Item label="选择终端" {...formItemLayout}>
              <Button onClick={this.handleTerminalSelectBtnClick} type="primary" size="small" icon="plus-circle-o">选择</Button>
              {userInfo.userCode ?
                <List
                  size="small"
                  bordered
                  style={{ width: '50%' }}
                  dataSource={[
                    `终端编号: ${userInfo.userCode}`,
                    `终端名称: ${userInfo.userName}`,
                    `所属校区: ${userInfo.campusName}`,
                    `所属渠道: ${userInfo.merchantName}`,
                  ]}
                  renderItem={item => <List.Item>{item}</List.Item>}
                />
              : null}
            </Form.Item>
            <Form.Item label="收货人" {...formItemLayout}>
              {getFieldDecorator('contactName', {
                rules: [{ required: true, type: 'string', message: '请填写收货人!' }],
                initialValue: userInfo.contactName,
              })(
                <Input style={{ width: "50%" }} placeholder="请填写或使用默认"/>
              )}
            </Form.Item>
            <Form.Item label="联系电话" {...formItemLayout}>
              {getFieldDecorator('mobile', {
                rules: [{ required: true, type: 'string', message: '请填写联系电话!' }],
                initialValue: userInfo.mobile,
              })(
                <Input style={{ width: "50%" }} placeholder="请填写或使用默认"/>
              )}
            </Form.Item>
            <Form.Item label="收货地址" {...formItemLayout}>
              {getFieldDecorator('address', {
                rules: [{ required: true, type: 'string', message: '请填写收货地址!' }],
                initialValue: userInfo.address,
              })(
                <Input.TextArea style={{ width: "50%" }} placeholder="请填写或使用默认"/>
              )}
            </Form.Item>
            <Form.Item label="添加备注" {...formItemLayout}>
              {getFieldDecorator('note', {
                initialValue: userInfo.note,
              })(
                <Input.TextArea style={{ width: "50%" }} placeholder="请输入(选填)" />
              )}
            </Form.Item>
            <Form.Item label="添加商品" {...formItemLayout}>
              <Button onClick={this.handleProductSelectBtnClick} disabled={userInfo.merchantId ? false : true} type="primary" size="small" icon="plus-circle-o">添加</Button>
              <Table
                bordered
                scroll={{ x: 1300 }}
                rowKey={record => record.id}
                pagination={false}
                columns={columns}
                dataSource={fmtProducts}
              />
            </Form.Item>
          </Form>
          {/*终端选择弹框*/}
          <TerminalSelectModal
            rowKeyName="id"
            modalVisible={terminalModalShow}
            style={{ top: 20 }}
            width={660}
            onOk={this.handleTerminalModalOk}
            onCancel={this.handleTerminalModalCancel}
            onSearch={this.handleTerminalModalSearch}
            fsTableDataSource={terminal.list || []}
            fsTableLoading={terminal.listLoading}
            fsTablePagination={terminal.pagination}
            fsTableOnChange={this.handleTerminalModalTableChange}
          />
          {/*渠道产品选择弹框*/}
          <MerchantProductSelectModal
            rowKeyName="id"
            modalVisible={productModalShow}
            selTableData={fmtProducts}
            style={{ top: 20 }}
            width={660}
            fsTableDataSource={mproduct.list}
            fsTableLoading={mproduct.listLoading}
            fsTablePagination={mproduct.pagination}
            onOk={this.handleProductModalOk}
            onCancel={this.handleProductModalCancel}
            onSearch={this.handleProductModalSearch}
            fsTableOnChange={this.handleProductModalTableChange}
          />
        </Card>
        <FooterToolbar>
          <Button onClick={this.handlePageCancel}>取消</Button>
          <Button type="primary">支付</Button>
        </FooterToolbar>
      </PageHeaderLayout>
    );
  }
}
